@@ -1,8 +1,10 @@
+import imp
 from labtex.unit import Unit, U
 from labtex.measurement import Measurement, M
 from labtex.measurementlist import MeasurementList, ML
 from labtex.linear import LinearRegression
+from labtex.nonlinear import NonlinearRegression
 from labtex.document import Document
 
 
-__version__ = '0.4.0'
\ No newline at end of file
+__version__ = '0.6.1'
\ No newline at end of file
